#!/usr/bin/env python
#
# TITLE:       SeqHoundRWeb.py 
# VERSION:     0.6 aka $Id: SeqHoundRWeb.py,v 1.4 2003/05/31 02:04:59 pete Exp $
# AUTHOR:      Pete St. Onge <pete@seul.org>
#              Based on proof of concept code by Paul Osman
#              <paul@codecipher.com>
# VERSION:     $Id: SeqHoundRWeb.py,v 1.4 2003/05/31 02:04:59 pete Exp $
# DESCRIPTION: A python wrapper for the seqhound remote functions 
#              accessible via the http interface at the seqhound web
#              site ( http://zaphod.mshri.on.ca/ ) - this is an
#              incomplete implementation of the http api calls at
#              http://seqhound.mshri.on.ca/httpcalls.html
#              API descriptions shameless stolen from the seqhound api
#              page at http://seqhound.mshri.on.ca/apifunctsdet.html
# USAGE:       Import into a python script (this is effectively a
#              library program
# TODO: - add config file handling, using the same rc file as seqhound
#         does, also support global (read: in /etc) config files.
#       - dump print statements in environment checking to stderr
#       - tidy up SeqHound{Uni|Duo|Tri|Quad} functions
#         get clearer list of error / problematic functions to seqhound
#         group

#######################################################################
# Imports here
#######################################################################
import urllib
import os

# Shamelessly copied from:
# http://www.python.org/doc/lib/module-urllib.html
class AppURLopener(urllib.FancyURLopener):
    def __init__(self, *args):
        self.version = "Seqhound Remote Web Python Module v. 0.6 ake $Id: SeqHoundRWeb.py,v 1.4 2003/05/31 02:04:59 pete Exp $"
        urllib.FancyURLopener.__init__(self, *args)

urllib._urlopener = AppURLopener()


print("seqhoundrweb.py: INITIATION of Seqhound Remote Web Python Module, v. $Id: SeqHoundRWeb.py,v 1.4 2003/05/31 02:04:59 pete Exp $\n")

# test for environment variables here
if os.environ.has_key('SEQHOUNDSITE'): 
    # yay, we found it. The next print line can be commented out in time
    SeqHoundSite = os.environ['SEQHOUNDSITE']
    print("seqhoundrweb.py: Using environment variable $SEQHOUNDSITE : %s" % SeqHoundSite )
else:
    print("seqhoundrweb.py: $SEQHOUNDSITE is NOT found.")
    TEXT = "seqhoundrweb.py: Testing for config file /etc/seqhound"
    if os.path.exists('/etc/seqhound'):
        print(" %s - FOUND.\n")
	# set environment here.
    else:
        print("%s - NOT found." % TEXT)
	print("seqhoundrweb.py: Using defaults.")
        SeqHoundSite="http://zaphod.mshri.on.ca"
	print("seqhoundrweb.py: SEQHOUNDSITE= %s\n" % SeqHoundSite)


# This should already have been dealt with above. But if not...
if os.environ.has_key('SEQHOUNDCGIPATH'): 
    # yay, we found it. The next line can be commented out in time
    SeqHoundCgiPath = os.environ['SEQHOUNDCGIPATH']
    print("seqhoundrweb.py: SEQHOUNDCGIPATH is found: %s" % SeqHoundCgiPath )
else:
    print("seqhoundrweb.py: SEQHOUNDCGIPATH is NOT found.")
    print("seqhoundrweb.py: Testing for config file /etc/seqhound.")
    if os.path.exists('/etc/seqhound'):
        print("seqhoundrweb.py: Config file found, setting environment\n.")
	# set environment here.
    else:
        print("seqhoundrweb.py: Configuration file not found,")
	print("seqhoundrweb.py: Using defaults.")
        SeqHoundCgiPath="cgi-bin/seqhound/seqrem"
        print("seqhoundrweb.py: SEQHOUNDCGIPATH = %s\n" % SeqHoundCgiPath)


#######################################################################
# Main Wrapper Functions
#######################################################################

# SeqHoundUni: Generic wrapper function for single parameter (bool)
#              seqhound functions.
def SeqHoundUni(params):
    p = urllib.urlencode({'fnct' : params[0]})
    print("%s/%s?%s" % (SeqHoundSite ,  SeqHoundCgiPath , p) )
    f = urllib.urlopen("%s/%s?%s" % (SeqHoundSite , SeqHoundCgiPath , p))
    a = f.read().split('\n')
    return a
if __name__ == "__main__":
    ret = SeqHoundUni(["SeqHoundIsNetEntrezOn"])


# SeqHoundDuo: Generic wrapper function for 2-parameter seqhound functions
def SeqHoundDuo(params):
    p = urllib.urlencode({'fnct' : params[0], params[1] : params[2]})
    print("%s/%s?%s" % (SeqHoundSite ,  SeqHoundCgiPath , p) )
    f = urllib.urlopen("%s/%s?%s" % (SeqHoundSite , SeqHoundCgiPath , p))
    a = f.read().split('\n')
    return a
if __name__ == "__main__":
    ret = SeqHoundDuo(["SeqHoundFindName", 1914689])


# SeqHoundTri: Generic wrapper function for 3-parameter seqhound
# functions
def SeqHoundTri(params):
    p = urllib.urlencode({'fnct' : params[0], params[1] : params[2], params[3] : params[4]})
    print("%s/%s?%s" % (SeqHoundSite ,  SeqHoundCgiPath , p) )
    f = urllib.urlopen("%s/%s?%s" % (SeqHoundSite , SeqHoundCgiPath , p))
    a = f.read().split('\n')
    return a
if __name__ == "__main__":
    ret = SeqHoundDuo(["SeqHoundFindName", 1914689])


# SeqHoundQuad: Generic wrapper function for 4-parameter seqhound
# functions
def SeqHoundQuad(params):
    p = urllib.urlencode({'fnct' : params[0], params[1] : params[2], params[3] : params[4], params[5] : params[6]})
    print("%s/%s?%s" % (SeqHoundSite ,  SeqHoundCgiPath , p) )
    f = urllib.urlopen("%s/%s?%s" % (SeqHoundSite , SeqHoundCgiPath , p))
    a = f.read().split('\n')
    return a
if __name__ == "__main__":
    ret = SeqHoundDuo(["SeqHoundFindName", 1914689])


# SeqHoundFind - Generic retrieval function
def SeqHoundFind(func, **keywords):
    a = {}
    a['fnct'] = func
    list = keywords.keys()
    for i in list:
        a.append(i)
    p = urllib.urlencode(a)
    print("%s/%s?%s" % (SeqHoundSite ,  SeqHoundCgiPath , p) )
    f = urllib.urlopen("%s/%s?%s" % (SeqHoundSite , SeqHoundCgiPath , p))
    return a
if __name__ == "__main__":
    ret = SeqHoundFind(["SeqHoundIsNetEntrezOn"])


# SeqStartError
def SeqStartError():
    Err_Text="\n"
    Err_Text="%s*************** SEQHOUND REMOTE WEB PYTHON MODULE ERROR ***************\n" % Err_Text
    Err_Text="%s \n"% Err_Text
    Err_Text="%s    There appears to have been some error in the initiation of the\n" % Err_Text
    Err_Text="%s    Seqhound Remote Web (Python) module (SeqHoundRWeb.py).\n" % Err_Text
    Err_Text="%s \n"% Err_Text
    Err_Text="%s    This could be for several reasons, here are some of the more\n" % Err_Text
    Err_Text="%s    likely ones:\n" % Err_Text
    Err_Text="%s    1) Be sure that the remote host given in the SEQHOUNDSITE\n" % Err_Text
    Err_Text="%s       (currently %s) used is correct\n" % (Err_Text, SeqHoundSite)
    Err_Text="%s    2) Be sure that the remote host is up and responding to pings\n" % Err_Text
    Err_Text="%s    3) Be sure that the seqhound cgi path (SEQHOUNDCGIPATH) on the\n" % Err_Text
    Err_Text="%s       above machine is correct (%s)\n" % (Err_Text, SeqHoundCgiPath)
    Err_Text="%s \n"% Err_Text
    Err_Text="%s    There should be an error message just above this box which should\n"% Err_Text
    Err_Text="%s    be useful in diagnosing the problem. The traceback below this box\n"% Err_Text
    Err_Text="%s    should also contain the error at the end of it. Good luck.\n"% Err_Text
    Err_Text="%s \n"% Err_Text
    Err_Text="%s    Pete St. Onge <pete@seul.org>, Maintainer. \n"% Err_Text
    Err_Text="%s \n"% Err_Text
    Err_Text="%s************** SEQHOUND REMOTE WEB PYTHON MODULE ERROR ***************" % Err_Text
    Err_Text="%s \n"% Err_Text
    print("%s" % Err_Text)


#######################################################################
# Main SeqHound Functions
#######################################################################

### SYSTEM INITIALIZATION, FINISHING AND TESTING
#
# SeqHoundInit

# SHoundIsNetEntrezOn:
def SeqHoundIsNetEntrezOn():
    a = SeqHoundUni(["SeqHoundIsNetEntrezOn"])
    return a
if __name__ == "__main__":
    ret = SeqHoundUni(["SeqHoundIsNetEntrezOn"])





### SEQUENCE IDENTIFIER CONVERSIONS

# SeqHoundFindAcc: Converts an accession number for a sequence into a
#                  GenInfo identifier - GI.
def SeqHoundFindAcc(params):
    a = SeqHoundDuo(["SeqHoundFindAcc", "acc", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundFindAcc(["CAA28783"])

# SeqHoundFindAccList: Converts a list of accession numbers into a list
#                      of GI identifiers.
# CAVEAT: the order in the lists is not maintained
def SeqHoundFindAccList(params):
    a = SeqHoundDuo(["SeqHoundFindAccList", "pacc", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundFindAccList(["CAA28783,X66994"])

# SeqHoundFindName: Converts PDB, EMBL, DDBJ, Swiss-Prot, PIR sequence
#                   identifier into a GI.
def SeqHoundFindName(params):
    a = SeqHoundDuo(["SeqHoundFindName", "name", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundFindName([1914689])

# SeqHoundFindNameList: Converts a list of PDB, EMBL, DDBJ, Swiss-Prot,
#                       PIR sequence identifiers into a list of GI 
#                       identifiers
# CAVEAT: the order in the lists is not maintained
def SeqHoundFindNameList(params):
    a = SeqHoundDuo(["SeqHoundFindNameList", "pname", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundFindNameList(['PMY14796,S36449,3TS1'])

# SeqHoundAccFromGi: Converts a GI identifier to an accession number.
def SeqHoundAccFromGi(params):
    a = SeqHoundDuo(["SeqHoundAccFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundAccFromGi([435])

# SeqHoundAccFromGiList: Converts a list of GI identifiers to a list of
#                        accession numbers.
# CAVEAT: the order in the lists is not maintained
def SeqHoundAccFromGiList(params):
    a = SeqHoundDuo(["SeqHoundAccFromGiList", "pgi",  params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundAccFromGiList(["123,34634"])

# SeqHoundSeqIdFromGi: Converts GI into an ASN.1 structure SeqId which
#                      contains all available identifiers for a given
#                      sequence.
def SeqHoundSeqIdFromGi(params):
    a = SeqHoundDuo(["SeqHoundSeqIdFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundSeqIdFromGi([432])


# SeqHoundSeqIdFromGiList: Converts a list of GI identifiers into an
#                          list of ASN.1 SeqId structures which contain
#                          all available identifiers for a given
#                          sequence.
# CAVEAT: the order in the lists is not maintained
def SeqHoundSeqIdFromGiList(params):
    a = SeqHoundDuo(["SeqHoundSeqIdFromGiList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundSeqIdFromGiList(["432,543"])


### DEFLINE FETCH 

# SeqHoundGetDefline: Fetches definition line for a sequence. Definition
#                     line contains the GI, accession number and other
#                     available identifiers together with a short
#                     description of the sequence.
def SeqHoundGetDefline(params):
    a = SeqHoundDuo(["SeqHoundGetDefline", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetDefline([4646])

# SeqHoundGetDeflineList: Fetches multiple definition lines for a list
#                         of sequences. Definition line contains the GI,
#                         accession number and other available
#                         identifiers together with a short description
#                         of the sequence.
# CAVEAT: the order in the lists is not maintained
def SeqHoundGetDeflineList(params):
    a = SeqHoundDuo(["SeqHoundGetDeflineList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetDeflineList(["2645003,480117,230940"])


### SEQUENCE AND STRUCTURE CHECKS

# SeqHoundIsProtein: Reports whether a given GI identifier denotes a
#                    protein (as opposed to DNA or RNA).
def SeqHoundIsProtein(params):
    a = SeqHoundDuo(["SeqHoundIsProtein", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundIsProtein([354])

# SeqHoundIsNRFirst: Reports if a given GI identifier represents the
#                    best annotated version from a group of database
#                    entries referring to the same protein sequence (so
#                    called redundant proteins).
def SeqHoundIsNRFirst(params):
    a = SeqHoundDuo(["SeqHoundIsNRFirst", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundIsNRFirst([3236312])

# SeqHoundExists: Reports whether a given GI identifier exists in the
#                 SeqHound system.
def SeqHoundExists(params):
    a = SeqHoundDuo(["SeqHoundExists", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundExists([34543])

# SeqHound3DbWhat: Finds out what kind of molecules are contained in a
#                  3-D structure.
def SeqHound3DbWhat(params):
    a = SeqHoundDuo(["SeqHound3DbWhat", "mmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DbWhat([3436])

# SeqHound3DExists: Finds out whether a given structural identifier
#                   (MMDB ID) exists in the system.
def SeqHound3DExists(params):
    a = SeqHoundDuo(["SeqHound3DExists", "mmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DExists([4534])


# SEQUENCE FETCH - ASN.1 BIOSEQ

# SeqHoundGetBioseq: Fetches ASN.1 representation of a sequence called
#                    Bioseq. The Bioseq is a structure used to represent
#                    a singe sequence, it contains all available
#                    annotation.
def SeqHoundGetBioseq(params):
    a = SeqHoundDuo(["SeqHoundGetBioseq", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetBioseq([535])
    
# SeqHoundGetBioseqList: Fetches a list of ASN.1 Bioseqs. The Bioseq is
#                        a structure used to represent a singe sequence,
#                        it contains all available annotation.
# CAVEAT: the order in the lists is not maintained
def SeqHoundGetBioseqList(params):
    a = SeqHoundDuo(["SeqHoundGetBioseqList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetBioseqList(["535,4534"])

# DOES NOT EXIST IN WEB API
#def SeqHoundGetXMLSeqEntry(params):
#    a = SeqHoundDuo(["SeqHoundGetXMLSeqEntry", "gi", params[0]])
#    return a
#if __name__ == "__main__":
#    ret = SeqHoundGetXMLSeqEntry([555])

# SEQUENCE FETCH - ASN.1 BIOSEQSET 

# SeqHoundGetBioseqSet: fetches ASN.1 representation of a sequence
#                       called BioseqSet. BioseqSet exists only if there
#                       is more than one sequence in logical group of
#                       sequences (e.g. gene and its protein product).
# ERRORS - 500 Internal Server Error
def SeqHoundGetBioseqSet(params):
    a = SeqHoundDuo(["SeqHoundGetBioseqSet", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetBioseqSet([666])

# SeqHoundGetBioseqSetList: Fetches a list of ASN.1 BioseqSets.
#                           BioseqSet exists only if there is more than
#                           one sequence in logical group of sequences
#                           (e.g. gene and its protein product).
# CAVEAT: the order in the lists is not maintained
# ERRORS - 500 Internal Server Error
def SeqHoundGetBioseqSetList(params):
    a = SeqHoundDuo(["SeqHoundGetBioseqSetList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetBioseqSetList(["666,555"])

# SeqHoundGetSeqEntry: Fetches ASN.1 representation of a sequence called
#                      SeqEntry. SeqEntry contains a single sequence or
#                      a group of sequences if they are logically
#                      related (e.g. gene and its protein product).
def SeqHoundGetSeqEntry(params):
    a = SeqHoundDuo(["SeqHoundGetSeqEntry", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetSeqEntry([234])

# SeqHoundGetSeqEntryList: Fetches a list of ASN.1 SeqEntries. SeqEntry
#                          contains a single sequence or a group of
#                          sequences if they are logically related (e.g.
#                          gene and its protein product).
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGetSeqEntryList(params):
    a = SeqHoundDuo(["SeqHoundGetSeqEntryList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetSeqEntryList(["342,555"])

# SEQUENCE FETCH - FASTA 

# SeqHoundGetFasta: Fetches FASTA formatted sequence. The FASTA format
#                   is widely used in bioinformatics community; it
#                   consists of a definition line, new line followed by
#                   a sequence terminated by a second new line.
def SeqHoundGetFasta(params):
    a = SeqHoundDuo(["SeqHoundGetFasta", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetFasta([666])

# SeqHoundGetFastaList: Fetches a list of FASTA formatted sequences. The
#                       FASTA format is widely used in bioinformatics
#                       community; it consists of a definition line, new
#                       line followed by a sequence terminated by a
#                       second new line.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGetFastaList(params):
    a = SeqHoundDuo(["SeqHoundGetFastaList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetFastaList(["666,555"])


### SEQUENCE FETCH - GENBANK FLAT FILE 

# SeqHoundGetGenBankff: Writes GenBank formatted sequence into a file.
#                       GenBank flat file contains comprehensive full
#                       annotation of a sequence.
def SeqHoundGetGenBankff(params):
    a = SeqHoundDuo(["SeqHoundGetGenBankff", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetGenBankff([32])

# SeqHoundGetGenBankffList: Writes a list of GenBank formatted sequences
#                           into a file. GenBank flat file contains
#                           comprehensive full annotation of a sequence.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGetGenBankffList(params):
    a = SeqHoundDuo(["SeqHoundGetGenBankffList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetGenBankffList(["32,666"])


# STRUCTURE FETCH - ASN.1 BIOSTRUC, PDB FORMAT, XML 

# SeqHoundGet3D: Fetches ASN.1 representation of 3-D structure called
#                Biostruc. Biostrucs represent data model in Molecular
#                Modeling database.
def SeqHoundGet3D(params):
    a = SeqHoundDuo(["SeqHoundGet3D", "mmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGet3D([32])

# SeqHoundGet3DfromPdbId: Fetches ASN.1 representation of 3-D structure
#                         called Biostruc. Biostrucs represent data
#                         model in Molecular Modeling database.
def SeqHoundGet3DfromPdbId(params):
    a = SeqHoundDuo(["SeqHoundGet3DfromPdbId", "pdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGet3DfromPdbId(["3INS"])

# SeqHoundGiFrom3D: Gets GI identifiers for sequence or sequences
#                   contained in 3-D structure. C argument(s): integer
#                   MMDB identifier and a boolean variable indicating if
#                   user wants to get only protein GI identifiers
def SeqHoundGiFrom3D(params):
    a = SeqHoundTri(["SeqHoundGiFrom3D", "mmdbid", params[0], "ProteinOnly", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFrom3D([23, "FALSE"])


# SeqHoundGiFrom3DList: Gets a list of GI sequence identifiers contained
#                       in a list of 3-D identifiers.
# CAVEAT: the order in the lists is not maintained
def SeqHoundGiFrom3DList(params):
    a = SeqHoundTri(["SeqHoundGiFrom3DList", "pmmdbid", params[0], "ProteinOnly", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFrom3DList(["23,32", "FALSE"])

# SeqHoundGiFromPDBchain: Gets a GI sequence identifier for a PDB
#                         structural chain. PDB code supplemented with a
#                         chain always refers to a single sequence.
def SeqHoundGiFromPDBchain(params):
    a = SeqHoundTri(["SeqHoundGiFromPDBchain", "pdbcode", params[0], "chain", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromPDBchain(["9XIM", "A"])

# SeqHound3DFromGi: Converts a GI sequence identifier to a structural
#                   MMDB identifier. Reports in which 3-D structure a
#                   particular sequence can be found.
def SeqHound3DFromGi(params):
    a = SeqHoundDuo(["SeqHound3DFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DFromGi([442560])

# SeqHound3DFromGiList: Converts a list of sequence GI identifiers to a
#                       list of structural MMDB identifiers.
# CAVEAT: the order in the lists is not maintained.
def SeqHound3DFromGiList(params):
    a = SeqHoundDuo(["SeqHound3DFromGiList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DFromGiList(["442560,442572"])

# SeqHoundDNAFromProtein: Converts an identifier to a protein (gene
#                         product) to an identifier to a nucleic acid
#                         (gene).
def SeqHoundDNAFromProtein(params):
    a = SeqHoundDuo(["SeqHoundDNAFromProtein", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromProtein([32])

# SeqHoundDNAFromProteinList: Converts a list of identifiers to proteins
#                             (gene products) to a list of identifiers
#                             to nucleic acids (genes).
# CAVEAT: the order in the lists is not maintained.
def SeqHoundDNAFromProteinList(params):
    a = SeqHoundDuo(["SeqHoundDNAFromProteinList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromProteinList(["325,4546"])

# SeqHoundProteinFromDNA: Converts an identifier to nucleic acid (gene)
#                         to one or more identifiers to proteins (gene
#                         products).
def SeqHoundProteinFromDNA(params):
    a = SeqHoundDuo(["SeqHoundProteinFromDNA", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinFromDNA([31])

# SeqHoundProteinFromDNAList: Converts a list of identifiers to nucleic
#                             acids (genes) to a list of identifiers to
#                             proteins (gene products).
# CAVEAT: the order in the lists is not maintained.
def SeqHoundProteinFromDNAList(params):
    a = SeqHoundDuo(["SeqHoundProteinFromDNAList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinFromDNAList(["324,4545"])

# SeqHoundMuidFromGi: Converts a sequence identifier to MEDLINE
#                     identifier to a publication. Fetches identifier to
#                     the original paper(s) discussing a given sequence.
def SeqHoundMuidFromGi(params):
    a = SeqHoundDuo(["SeqHoundMuidFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundMuidFromGi([32])

# SeqHoundMuidFromGiList: Converts a list sequence identifier into a
#                         list of MEDLINE identifiers to a publications.
#                         Fetches identifiers to the original papers
#                         discussing given sequences.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundMuidFromGiList(params):
    a = SeqHoundDuo(["SeqHoundMuidFromGiList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundMuidFromGiList(["324,32"])

# SeqHoundMuidFrom3D: Converts a structural identifier to a one or more
#                     MEDLINE identifier. Fetches an identifier to the
#                     original paper discussing a given 3-D structure.
def SeqHoundMuidFrom3D(params):
    a = SeqHoundDuo(["SeqHoundMuidFrom3D", "mmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundMuidFrom3D([11])

# SeqHoundMuidFrom3DList: Converts a list of structural identifiers to a
#                         list of MEDLINE identifiers. Fetches
#                         identifiers to the original papers discussing
#                         given 3-D structures.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundMuidFrom3DList(params):
    a = SeqHoundDuo(["SeqHoundMuidFrom3DList", "pmmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundMuidFrom3DList(["11,12"])

# SeqHoundTaxIDFromGi: Converts a sequence identifier to an NCBI
#                      taxonomy identifier i.e. reports what organism a
#                      given sequence is from.
def SeqHoundTaxIDFromGi(params):
    a = SeqHoundDuo(["SeqHoundTaxIDFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundTaxIDFromGi([32])

# SeqHoundTaxIDFromGiList: Converts a list of sequence identifiers to a
#                          list of NCBI taxonomy identifier i.e. reports
#                          what organisms given sequences are from.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundTaxIDFromGiList(params):
    a = SeqHoundDuo(["SeqHoundTaxIDFromGiList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundTaxIDFromGiList(["324,32"])

# SeqHoundTaxIDFrom3D: Converts a structural identifier to one or more
#                      taxonomy identifiers i.e. reports what
#                      organism(s) the 3-D struct
def SeqHoundTaxIDFrom3D(params):
    a = SeqHoundDuo(["SeqHoundTaxIDFrom3D", "mmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundTaxIDFrom3D([11])

# SeqHoundTaxIDFrom3DList: Converts a list of structural identifiers to
#                          a list of taxonomy identifiers i.e. reports
#                          what organisms the 3-D structures come from.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundTaxIDFrom3DList(params):
    a = SeqHoundDuo(["SeqHoundTaxIDFrom3DList", "pmmdbid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundTaxIDFrom3DList(["11,12"])

# SeqHoundProteinsFromTaxID: Gets all protein sequence identifiers from
#                            one organism.
def SeqHoundProteinsFromTaxID(params):
    a = SeqHoundDuo(["SeqHoundProteinsFromTaxID", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromTaxID([10665])

# SeqHoundProteinsFromTaxIDIII: Gets all protein sequence identifiers
#                               from one organism. The function takes
#                               advantage of precomputed searches it the
#                               appropriate one is available.
def SeqHoundProteinsFromTaxIDIII(params):
    a = SeqHoundDuo(["SeqHoundProteinsFromTaxIDIII", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromTaxIDIII([10665])

# SeqHoundProteinsFromTaxIDList: Gets all protein sequence identifiers
#                                from a list of organisms.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundProteinsFromTaxIDList(params):
    a = SeqHoundDuo(["SeqHoundProteinsFromTaxIDList", "ptaxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromTaxIDList(["10665"])

# SeqHoundDNAFromTaxID: Gets all nucleic acid sequence identifiers from
#                       one organism.
def SeqHoundDNAFromTaxID(params):
    a = SeqHoundDuo(["SeqHoundDNAFromTaxID", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromTaxID([10665])

# SeqHoundDNAFromTaxIDIII: Gets all nucleic acid sequence identifiers
#                          from one organism. The function takes
#                          advantage of precomputed searches it the
#                          appropriate one is available.
def SeqHoundDNAFromTaxIDIII(params):
    a = SeqHoundDuo(["SeqHoundDNAFromTaxIDIII", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromTaxIDIII([10665])

# SeqHoundDNAFromTaxIDList: Gets all nucleic acid sequence identifiers
#                           from a list of organisms.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundDNAFromTaxIDList(params):
    a = SeqHoundDuo(["SeqHoundDNAFromTaxIDList", "ptaxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromTaxIDList(["10665"])


### COMPLETE GENOME ITERATORS

# SeqHoundProteinsFromOrganism: Gets all protein identifiers from a
#                               complete genome annotation. Complete
#                               genome annotations are available from
#                               NCBI.
# Comment: The arguments concerning DNA molecule type are so called
#          "byte flags" where each bit is reserved for one kind of DNA
#          molecules: the input values are decimal numbers representing
#          above mentioned byte flags:
#
#        1 is chromosome
#        2 is mitochondrion
#        4 is chloroplast
#        8 is plasmid
#       16 is extra-chromosomal element
#       32 is undefined
#       64 is phage
#      255 is all 
def SeqHoundProteinsFromOrganism(params):
    a = SeqHoundTri(["SeqHoundProteinsFromOrganism", "taxid", params[0], "chromflags", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromOrganism([155864, 1])

# SeqHoundProteinsFromOrganismList: Gets all protein identifiers from a
#                                   complete genomes list. Complete
#                                   genome annotations are available
#                                   from NCBI.
# COMMENT: See above (SeqHoundProteinsFromOrganism) for bit list.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundProteinsFromOrganismList(params):
    a = SeqHoundTri(["SeqHoundProteinsFromOrganismList", "ptaxid", params[0], "chromflags", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromOrganismList(["155864,139", 1])

# SeqHoundProteinsFromChromosome: Gets all protein identifiers from one
#                                 DNA molecule such as chromosome,
#                                 plasmid etc. The resulting protein
#                                 identifiers constitute a subset of
#                                 complete genome annotation available
#                                 from NCBI.
def SeqHoundProteinsFromChromosome(params):
    a = SeqHoundDuo(["SeqHoundProteinsFromChromosome", "chromid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromChromosome([169])

# SeqHoundProteinsFromChromosomeList: Gets all protein identifiers from
#                                     a list DNA molecules such as
#                                     chromosomes, plasmids etc. The
#                                     resulting protein identifiers
#                                     constitute a subset of complete
#                                     genome annotation available from
#                                     NCBI.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundProteinsFromChromosomeList(params):
    a = SeqHoundDuo(["SeqHoundProteinsFromChromosomeList", "pchromid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundProteinsFromChromosomeList(["169,132"])


# SeqHoundAllGenomes: Gets a list of taxonomy identifiers for all
#                     complete genomes present in the SeqHound system.
#                     Complete genome annotations are available from
#                     NCBI.
def SeqHoundAllGenomes(params):
    a = SeqHoundUni(["SeqHoundAllGenomes"])
    return a
if __name__ == "__main__":\
    ret = SeqHoundUni(["SeqHoundAllGenomes", "nothinghere"])

# SeqHoundChromosomeFromGenome: Gets a list of DNA molecules from a
#                               complete genome. The desired return
#                               types of DNA molecules can be filtered.
# COMMENT: Bit list is identical to that given for
# SeqHoundProteinsFromOrganism
def SeqHoundChromosomeFromGenome(params):
    a = SeqHoundTri(["SeqHoundChromosomeFromGenome", "taxid", params[0], "chromflags", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundChromosomeFromGenome([155864, 1])

# SeqHoundChromosomeFromGenomeList: Gets a list of DNA molecules from a
#                                   complete genome list. The desired
#                                   return types of DNA molecules can be
#                                   filtered.
# COMMENT: Bit list is identical to that given for
# SeqHoundProteinsFromOrganism
# CAVEAT: the order in the lists is not maintained.
def SeqHoundChromosomeFromGenomeList(params):
    a = SeqHoundTri(["SeqHoundChromosomeFromGenomeList", "ptaxid", params[0], "chromflags", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundChromosomeFromGenomeList(["155864", 1])

# SeqHoundDNAFromOrganism: Gets all DNA identifiers from a complete
#                          genome annotation. Complete genome
#                          annotations are available from NCBI.
# COMMENT: Bit list is identical to that given for
# SeqHoundProteinsFromOrganism
def SeqHoundDNAFromOrganism(params):
    a = SeqHoundTri(["SeqHoundDNAFromOrganism", "taxid", params[0], "chromflags", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromOrganism([155864, 1])

# SeqHoundDNAFromOrganismList: Gets all DNA identifiers from a complete
#                              genomes list. Complete genome annotations
#                              are available from NCBI.
# COMMENT: Bit list is identical to that given for
# SeqHoundProteinsFromOrganism
# CAVEAT: the order in the lists is not maintained. 
def SeqHoundDNAFromOrganismList(params):
    a = SeqHoundTri(["SeqHoundDNAFromOrganismList", "ptaxid", params[0], "chromflags", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromOrganismList(["155864,139", 1])

# SeqHoundDNAFromChromosome: Gets all DNA identifiers from one DNA
#                            molecule such as chromosome, plasmid etc.
#                            The resulting DNA identifiers constitute a
#                            subset of complete genome annotation
#                            available from NCBI.
def SeqHoundDNAFromChromosome(params):
    a = SeqHoundDuo(["SeqHoundDNAFromChromosome", "chromid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromChromosome([169])

# SeqHoundDNAFromChromosomeList: Gets all DNA identifiers from a list DNA
#                                molecules such as chromosomes, plasmids
#                                etc. The resulting DNA identifiers
#                                constitute a subset of complete genome
#                                annotation available from NCBI.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundDNAFromChromosomeList(params):
    a = SeqHoundDuo(["SeqHoundDNAFromChromosomeList", "pchromid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundDNAFromChromosomeList(["169,132"])


### REDUNDANT (EQUIVALENT) SEQUENCES

# SeqHoundRedundantGroup: Entrez collection of databases contains
#                         redundant entries i.e. proteins with the same
#                         sequence but different annotations. The
#                         function gets all protein entries with the
#                         same sequence from the system.
def SeqHoundRedundantGroup(params):
    a = SeqHoundDuo(["SeqHoundRedundantGroup", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundRedundantGroup([32])

# SeqHoundRedundantGroupList: Entrez collection of databases contains
#                             redundant entries i.e. proteins with the
#                             same sequence but different annotations.
#                             The function gets all protein entries with
#                             the same sequence from the system for a
#                             list of protein sequences.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundRedundantGroupList(params):
    a = SeqHoundDuo(["SeqHoundRedundantGroupList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundRedundantGroupList(["32,4586891"])


# SeqHoundRedundantGroupIDFromGI: Entrez collection of databases
#                                 contains redundant entries i.e.
#                                 proteins with the same sequence but
#                                 different annotations. The function
#                                 gets an arbitrary redundant group
#                                 identifier for a protein sequence. The
#                                 redundant group identifiers can only
#                                 be used temporarily, they change every
#                                 day.
def SeqHoundRedundantGroupIDFromGI(params):
    a = SeqHoundDuo(["SeqHoundRedundantGroupIDFromGI", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundRedundantGroupIDFromGI([32])

# SeqHoundRedundantGroupIDFromGIList: Entrez collection of databases
#                                     contains redundant entries i.e.
#                                     proteins with the same sequence
#                                     but different annotations. The
#                                     function gets an arbitrary
#                                     redundant group identifier for a
#                                     list of protein sequences. The
#                                     redundant group identifiers can
#                                     only be used temporarily, they
#                                     change every day.
# CAVEAT: The order in the lists is probably not maintained (not
#         mentioned in the api documents)
def SeqHoundRedundantGroupIDFromGIList(params):
    a = SeqHoundDuo(["SeqHoundRedundantGroupIDFromGIList", "pgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundRedundantGroupIDFromGIList(["32,6017926"])

# SeqHoundRedundantGroupFromID: Entrez collection of databases contains
#                               redundant entries i.e. proteins with the
#                               same sequence but different annotations.
#                               The function gets a list of redundant
#                               protein sequences from a redundant group
#                               identifier. The redundant group
#                               identifiers can only be used
#                               temporarily, they change every day.
def SeqHoundRedundantGroupFromID(params):
    a = SeqHoundDuo(["SeqHoundRedundantGroupFromID", "group", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundRedundantGroupFromID([362477])

# SeqHoundRedundantGroupFromIDList: Entrez collection of databases
#                                   contains redundant entries i.e.
#                                   proteins with the same sequence but
#                                   different annotations. The function
#                                   gets a list of redundant protein
#                                   sequences from a list of redundant
#                                   group identifiers. The redundant
#                                   group identifiers can only be used
#                                   temporarily, they change every day.
# CAVEAT: The order in the lists is probably not maintained (not
#         mentioned in the api documents)
def SeqHoundRedundantGroupFromIDList(params):
    a = SeqHoundDuo(["SeqHoundRedundantGroupFromIDList", "pgroup", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundRedundantGroupFromIDList(["32,362477"])

# SeqHoundFirstOfRedundantGroupFromID: Entrez collection of databases
#                                      contains redundant entries i.e.
#                                      proteins with the same sequence
#                                      but different annotations. The
#                                      function gets a representative
#                                      entry (generally the one with
#                                      best annotation such as PDB,
#                                      RefSeq or SwissProt entry) given
#                                      a redundant group identifier. The
#                                      redundant group identifiers can
#                                      only be used temporarily, they
#                                      change every day.
def SeqHoundFirstOfRedundantGroupFromID(params):
    a = SeqHoundDuo(["SeqHoundFirstOfRedundantGroupFromID", "group", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundFirstOfRedundantGroupFromID([362477])

# SeqHoundFirstOfRedundantGroupFromIDList: Entrez collection of
#                                          databases contains redundant
#                                          entries i.e. proteins with
#                                          the same sequence but
#                                          different annotations. The
#                                          function gets a list of
#                                          representative entries
#                                          (generally the one with best
#                                          annotation such as PDB,
#                                          RefSeq or SwissProt entry)
#                                          given a list of redundant
#                                          group identifiers. The
#                                          redundant group identifiers
#                                          can only be used temporarily,
#                                          they change every day.
# CAVEAT: The order in the lists is probably not maintained (not
#         mentioned in the api documents)
def SeqHoundFirstOfRedundantGroupFromIDList(params):
    a = SeqHoundDuo(["SeqHoundFirstOfRedundantGroupFromIDList", "pgroup", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundFirstOfRedundantGroupFromIDList(["362477,408917"])


### TAXONOMY 

# SeqHoundGetTaxChildNodes: This function operates on NCBI's taxonomy
#                           tree. It retrieves all taxons situated
#                           directly below a given taxon in the taxonomy
#                           tree.
def SeqHoundGetTaxChildNodes(params):
    a = SeqHoundDuo(["SeqHoundGetTaxChildNodes", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetTaxChildNodes([10665])

# SeqHoundGetTaxChildNodesList: This function operates on NCBI's
#                               taxonomy tree. It retrieves all taxons
#                               situated directly below a list of taxons
#                               in the taxonomy tree.
# CAVEAT: The order in the lists is not maintained.
def SeqHoundGetTaxChildNodesList(params):
    a = SeqHoundDuo(["SeqHoundGetTaxChildNodesList", "ptaxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetTaxChildNodesList(["10665"])

# SeqHoundGetAllTaxProgeny: This function operates on NCBI's taxonomy
#                           tree. It retrieves all taxons (the whole
#                           subtree) situated below a given taxon in the
#                           taxonomy tree.
def SeqHoundGetAllTaxProgeny(params):
    a = SeqHoundDuo(["SeqHoundGetAllTaxProgeny", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetAllTaxProgeny([10665])

# SeqHoundGetTaxParent: This function operates on NCBI's taxonomy tree.
#                       It retrieves taxon situated directly above a
#                       given taxon in the taxonomy tree.
def SeqHoundGetTaxParent(params):
    a = SeqHoundDuo(["SeqHoundGetTaxParent", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetTaxParent([10665])

# SeqHoundGetAllTaxAncestors: This function operates on NCBI's taxonomy
#                             tree. It retrieves all taxons (the whole
#                             subtree) situated above a given taxon in
#                             the taxonomy tree.
def SeqHoundGetAllTaxAncestors(params):
    a = SeqHoundDuo(["SeqHoundGetAllTaxAncestors", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetAllTaxAncestors([10665])

# SeqHoundIsTaxMerged: This function operates on NCBI's taxonomy tree.
#                      It reports if a given taxon has been renamed.
def SeqHoundIsTaxMerged(params):
    a = SeqHoundDuo(["SeqHoundIsTaxMerged", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundIsTaxMerged([10665])

# SeqHoundIsTaxDeleted: This function operates on NCBI's taxonomy tree.
#                       It reports if a given taxon has been deleted.
def SeqHoundIsTaxDeleted(params):
    a = SeqHoundDuo(["SeqHoundIsTaxDeleted", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundIsTaxDeleted([10665])


# SeqHoundGetTaxNameFromTaxIDByClass: This function operates on NCBI's
#                                     taxonomy tree. It fetches a
#                                     taxonomy name in a specified
#                                     style.
# comment: The name form can be specified using the following defines:
# SLRI_taxon_name_name_class_none                    0
# SLRI_taxon_name_name_class_acronym                 1
# SLRI_taxon_name_name_class_anamorph                2
# SLRI_taxon_name_name_class_blast_name              3
# SLRI_taxon_name_name_class_common_name             4
# SLRI_taxon_name_name_class_equivalent_name         5
# SLRI_taxon_name_name_class_includes                6
# SLRI_taxon_name_name_class_in_part                 7
# SLRI_taxon_name_name_class_misnomer                8
# SLRI_taxon_name_name_class_misspelling             9
# SLRI_taxon_name_name_class_preferred_acronym      10
# SLRI_taxon_name_name_class_preferred_common_name  11
# SLRI_taxon_name_name_class_scientific_name        12
# SLRI_taxon_name_name_class_synonym                13
# SLRI_taxon_name_name_class_teleomorph             14
# SLRI_taxon_name_name_class_other                 255
def SeqHoundGetTaxNameFromTaxIDByClass(params):
    a = SeqHoundTri(["SeqHoundGetTaxNameFromTaxIDByClass", "taxid", params[0], "type", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetTaxNameFromTaxIDByClass([9606, 11])

# SeqHoundGetTaxNameFromTaxID: This function operates on NCBI's taxonomy
#                              tree. It fetches a taxonomy name in a
#                              scientific form.
def SeqHoundGetTaxNameFromTaxID(params):
    a = SeqHoundDuo(["SeqHoundGetTaxNameFromTaxID", "taxid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetTaxNameFromTaxID([9606])


## SeqHoundGetTaxLineageFromTaxID: This function operates on NCBI's
#                                  taxonomy tree. It fetches a taxonomy
#                                  name in a scientific form.
def SeqHoundGetTaxLineageFromTaxID(params):
    a = SeqHoundTri(["SeqHoundGetTaxLineageFromTaxID", "taxid", params[0], "type", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetTaxLineageFromTaxID(9606, 1)


### SEQUENCE NEIGHBOURS

# SeqHoundGetBlastResult: Retrieves summary information about a BLAST
#                         alignment between two protein sequences.
def SeqHoundGetBlastResult(params):
    a = SeqHoundTri(["SeqHoundGetBlastResult", "gi1", params[0], "gi2", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetBlastResult([6017926 ,32])


# SeqHoundGetBlastSeqAlign: Retrieves detailed information about a BLAST
#                           alignment between two protein sequences.
def SeqHoundGetBlastSeqAlign(params):
    a = SeqHoundTri(["SeqHoundGetBlastSeqAlign", "gi1", params[0], "gi2", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetBlastSeqAlign([6017926 ,32])

# SeqHoundNeighboursFromGiEx: Retrieves a list of protein BLAST
#                             neighbours. The BLAST protein neighbours
#                             were calculated using 0.01 maximum E-value
#                             cutoff.
def SeqHoundNeighboursFromGiEx(params):
    a = SeqHoundQuad(["SeqHoundNeighboursFromGiEx", "gi", params[0], "evalue", params[1], "bLimit", params[2]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursFromGiEx([6017926, 0.1, "FALSE"])

# SeqHoundNeighboursFromGi: Retrieves a list of protein BLAST
#                           neighbours. Uses redundancy information for
#                           the query protein. The BLAST protein
#                           neighbours were calculated using 0.01
#                           maximum E-value cutoff. 
def SeqHoundNeighboursFromGi(params):
    a = SeqHoundQuad(["SeqHoundNeighboursFromGi", "gi", params[0], "evalue", params[1], "bLimit", params[2]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursFromGi([6017926, 0.1, "FALSE"])

# SeqHoundNeighboursFromGiList: Retrieves a list of protein BLAST
#                               neighbours using a list of proteins as a
#                               query. Uses redundancy information for
#                               the query proteins. The BLAST protein
#                               neighbours were calculated using 0.01
#                               maximum E-value cutoff.
# CAVEAT: The order in the lists is probably not maintained (not
#         mentioned in the api documents)
def SeqHoundNeighboursFromGiList(params):
    a = SeqHoundTri(["SeqHoundNeighboursFromGiList", "gilist", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursFromGiList(["6017926,32",0.01])
	    
# SeqHoundNeighboursFromTaxID: Retrieves a list of protein BLAST
#                              neighbours using a list of proteins
#                              belonging to a complete genome as a
#                              query. Uses redundancy information for
#                              the query proteins. The BLAST protein
#                              neighbours were calculated using 0.01
#                              maximum E-value cutoff.
def SeqHoundNeighboursFromTaxID(params):
    a = SeqHoundTri(["SeqHoundNeighboursFromTaxID", "taxid", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursFromTaxID([2097,0.01]) 
	    
# SeqHoundNeighboursOfNeighbours: Retrieves a list of protein BLAST
#                                 neighbours using a list of proteins
#                                 constituting neighbours to a given
#                                 protein as a query. Uses redundancy
#                                 information for the query proteins.
#                                 The BLAST protein neighbours were
#                                 calculated using 0.01 maximum E-value
#                                 cutoff.
def SeqHoundNeighboursOfNeighbours(params):
    a = SeqHoundTri(["SeqHoundNeighboursOfNeighbours", "gi", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursOfNeighbours([68502, 0.01])
	    
# SeqHoundNeighboursOfNeighboursList: Retrieves a list of protein BLAST
#                                     neighbours using a list of
#                                     proteins constituting neighbours
#                                     to a given list of proteins as a
#                                     query. Uses redundancy information
#                                     for the query proteins. The BLAST
#                                     protein neighbours were calculated
#                                     using 0.01 maximum E-value cutoff.
# CAVEAT: The order in the lists is probably not maintained (not
#         mentioned in the api documents)
def SeqHoundNeighboursOfNeighboursList(params):
    a = SeqHoundTri(["SeqHoundNeighboursOfNeighboursList", "gilist", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursOfNeighboursList(["68502,266373", 0.01])
	    
# SeqHoundNeighboursOfNeighboursFromTaxID: Retrieves a list of protein
#                                          BLAST neighbours using a list
#                                          of proteins constituting a
#                                          complete genome as a query.
#                                          Uses redundancy information
#                                          for the query proteins.  The
#                                          BLAST protein neighbours were
#                                          calculated using 0.01 maximum
#                                          E-value cutoff.
def SeqHoundNeighboursOfNeighboursFromTaxID(params):
    a = SeqHoundTri(["SeqHoundNeighboursOfNeighboursFromTaxID", "taxid", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundNeighboursOfNeighboursFromTaxID([2097, 0.01])
	    
# SeqHound3DNeighboursFromGiEx: Retrieves a list of protein BLAST
#                               neighbours possessing 3-D structure.
#                               Uses redundancy information for the
#                               query protein. The BLAST protein
#                               neighbours were calculated using 0.01
#                               maximum E-value cutoff.
def SeqHound3DNeighboursFromGiEx(params):
    a = SeqHoundTri(["SeqHound3DNeighboursFromGiEx", "gi", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret =  SeqHound3DNeighboursFromGiEx([2097, 0.01]) 
	    
# SeqHound3DNeighboursFromGi: Retrieves a list of protein BLAST
#                             neighbours possessing 3-D structure. Uses
#                             redundancy information for the query
#                             protein. The BLAST protein neighbours were
#                             calculated using 0.01 maximum E-value
#                             cutoff.
def SeqHound3DNeighboursFromGi(params):
    a = SeqHoundTri(["SeqHound3DNeighboursFromGi", "gi", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DNeighboursFromGi([68502, 0.01])
    
# SeqHound3DNeighboursFromGiList: Retrieves a list of protein BLAST
#                                 neighbours possessing 3-D structure
#                                 using a list of proteins as a query.
#                                 Uses redundancy information for the
#                                 query protein. The BLAST protein
#                                 neighbours were calculated using 0.01
#                                 maximum E-value cutoff.
# CAVEAT: The order in the lists is probably not maintained (not
#         mentioned in the api documents)
def SeqHound3DNeighboursFromGiList(params):
    a = SeqHoundTri(["SeqHound3DNeighboursFromGiList", "gilist", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DNeighboursFromGiList(["68502,266373", 0.01])
	    
# SeqHound3DNeighboursFromTaxID: Retrieves a list of protein BLAST
#                                neighbours possessing 3-D structure
#                                using a list of proteins belonging to a
#                                complete genome as a query. Uses
#                                redundancy information for the query
#                                protein. The BLAST protein neighbours
#                                were calculated using 0.01 maximum
#                                E-value cutoff.
def SeqHound3DNeighboursFromTaxID(params):
    a = SeqHoundTri(["SeqHound3DNeighboursFromTaxID", "taxid", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DNeighboursFromTaxID([2097, 0.01])
	    
# SeqHound3DListFromTaxID: 
def SeqHound3DListFromTaxID(params):
    a = SeqHoundDuo(["SeqHound3DListFromTaxID", "taxid=value", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHound3DListFromTaxID([2097])

# SeqHoundGiAndNumNeighboursList: Retrieves a number of neighbours for
#                                 each protein in the database. The
#                                 BLAST protein neighbours were
#                                 calculated using 0.01 maximum E-value
#                                 cutoff.
def SeqHoundGiAndNumNeighboursList(params):
    a = SeqHoundUni(["SeqHoundGiAndNumNeighboursList"])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiAndNumNeighboursList([])

# SeqHoundNumNeighboursInDB: Retrieves a number of neighbours for each
#                            protein in the database. The BLAST protein
#                            neighbours were calculated using 0.01
#                            maximum E-value cutoff.
def SeqHoundNumNeighboursInDB(params):
    a = SeqHoundUni(["SeqHoundNumNeighboursInDB"])
    return a
if __name__ == "__main__":
    ret = SeqHoundNumNeighboursInDB([])


### FUNCTIONAL ANNOTATION

# SeqHoundGiFromGOID: Fetches all protein sequences which were assigned
#                     a given Gene Ontology (GO) function, process or
#                     component.
def SeqHoundGiFromGOID(params):
    a = SeqHoundDuo(["SeqHoundGiFromGOID", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromGOID([8320])


# SeqHoundGiFromGOIDList: Fetches all protein sequences which were
#                         assigned a list of Gene Ontology (GO)
#                         functions, processes or components.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGiFromGOIDList(params):
    a = SeqHoundDuo(["SeqHoundGiFromGOIDList", "vnpgo", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromGOIDList(["8320,5737"])

# SeqHoundGOIDFromGi: Fetches all Gene Ontology (GO) terms assigned to a
#                      protein sequence. An individual sequence can be
#                      referred to by one or more process, function or
#                      component terms.
def SeqHoundGOIDFromGi(params):
    a = SeqHoundDuo(["SeqHoundGOIDFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGOIDFromGi([15149484])

# SeqHoundGOIDFromGiList: Fetches all Gene Ontology (GO) terms assigned
#                         to a list of protein sequences. An individual
#                         sequence can be referred to by one or more
#                         process, function or component terms.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGOIDFromGiList(params):
    a = SeqHoundDuo(["SeqHoundGOIDFromGiList", "vnpgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGOIDFromGiList(["15149484,6912624"])

# SeqHoundGOIDFromRedundantGi: Fetches all Gene Ontology (GO) terms
#                              assigned to a protein sequence. Uses
#                              redundancy information for the query
#                              protein. An individual sequence can be
#                              referred to by one or more a process,
#                              function or component terms.
def SeqHoundGOIDFromRedundantGi(params):
    a = SeqHoundDuo(["SeqHoundGOIDFromRedundantGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGOIDFromRedundantGi([15149484])

# SeqHoundGOIDFromRedundantGiList: Fetches all Gene Ontology (GO) terms
#                                  assigned to a list of protein
#                                  sequences. Uses redundancy
#                                  information for the query proteins.
#                                  An individual sequence can be
#                                  referred to by one or more a process,
#                                  function or component terms.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGOIDFromRedundantGiList(params):
    a = SeqHoundDuo(["SeqHoundGOIDFromRedundantGiList", "vnpgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGOIDFromRedundantGiList(["15149484,6912624"])

# SeqHoundGOECodeFromGi: Fetches one or more Gene Ontology evidence code
#                        documenting a source of ontology assignment.
#                        The evidence codes were adopted from NCBI's
#                        LocusLink annotation.
def SeqHoundGOECodeFromGi(params):
    a = SeqHoundDuo(["SeqHoundGOECodeFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGOECodeFromGi([4501841])

# SeqHoundGOPMIDFromGi: Fetches one or more PubMed (equivalent to
#                       MEDLINE) identifiers documenting a source of
#                       ontology assignment. The publication assignments
#                       were adopted from NCBI's LocusLink annotation.
def SeqHoundGOPMIDFromGi(params):
    a = SeqHoundDuo(["SeqHoundGOPMIDFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGOPMIDFromGi([4501841])

# SeqHoundGiFromOMIM: Fetches all sequences associated with an entry in
#                     Online Mendelian Inheritance in Man (OMIM)
#                     database.
def SeqHoundGiFromOMIM(params):
    a = SeqHoundDuo(["SeqHoundGiFromOMIM", "omimid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromOMIM([103950])

# SeqHoundGiFromOMIMList: Fetches all sequences associated with a list
#                         of entries in Online Mendelian Inheritance in
#                         Man (OMIM) database.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGiFromOMIMList(params):
    a = SeqHoundDuo(["SeqHoundGiFromOMIMList", "vnpomim", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromOMIMList(["137150,103950,108345"])

# SeqHoundOMIMFromGi: Fetches Online Mendelian Inheritance in Man (OMIM)
#                     database identifiers associated with a sequence.
def SeqHoundOMIMFromGi(params):
    a = SeqHoundDuo(["SeqHoundOMIMFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundOMIMFromGi([4505335])

# SeqHoundOMIMFromGiList: Fetches Online Mendelian Inheritance in Man
#                         (OMIM) database identifiers associated with a
#                         list of sequences.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundOMIMFromGiList(params):
    a = SeqHoundDuo(["SeqHoundOMIMFromGiList", "vnpgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundOMIMFromGiList(["4501841,4557225"])

# SeqHoundGiFromCDDID: Fetches all sequences carrying a domain from
#                      Conserved Domain Database (CDD) as determined by
#                      Reverse Position Specific BLAST.
def SeqHoundGiFromCDDID(params):
    a = SeqHoundDuo(["SeqHoundGiFromCDDID", "cddid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromCDDID(["pfam00664"])

# SeqHoundGiFromCDDIDList: Fetches all sequences carrying a list of
#                          domains from Conserved Domain Database (CDD)
#                          as determined by Reverse Position Specific
#                          BLAST.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGiFromCDDIDList(params):
    a = SeqHoundDuo(["SeqHoundGiFromCDDIDList", "vnpcdd", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromCDDIDList(["pfam00202,pfam01835,pfam00079,smart00231"])

# SeqHoundCDDIDFromGi: Fetches domains from Conserved Domain Database
#                      (CDD) as determined by Reverse Position Specific
#                      BLAST on a given sequence.
def SeqHoundCDDIDFromGi(params):
    a = SeqHoundDuo(["SeqHoundCDDIDFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundCDDIDFromGi([4557225])

# SeqHoundCDDIDFromGiList: Fetches domains from Conserved Domain
#                          Database (CDD) as determined by Reverse
#                          Position Specific BLAST on a list of
#                          sequences.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundCDDIDFromGiList(params):
    a = SeqHoundDuo(["SeqHoundCDDIDFromGiList", "vnpgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundCDDIDFromGiList(["4501841,4557225"])

# SeqHoundCDDScoreFromGi: Fetches a score for Conserved Domain Database
#                         (CDD) domain assignment as determined by
#                         Reverse Position Specific BLAST.
def SeqHoundCDDScoreFromGi(params):
    a = SeqHoundTri(["SeqHoundCDDScoreFromGi", "gi", params[0], "cddid", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundCDDScoreFromGi([4505769, "pfam00202"])
    
# SeqHoundGiFromLLID: Fetches sequences associated with NCBI's LocusLink
#                     database entry.
def SeqHoundGiFromLLID(params):
    a = SeqHoundDuo(["SeqHoundGiFromLLID", "llid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromLLID([9])

# SeqHoundGiFromLLIDList: Fetches sequences associated with a list of
#                         NCBI's LocusLink database entry.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundGiFromLLIDList(params):
    a = SeqHoundDuo(["SeqHoundGiFromLLIDList", "vnpll", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiFromLLIDList(["1,2,13"])

# SeqHoundLLIDFromGi: Fetches an NCBI's LocusLink database identifier
#                     associated with a given sequence.
def SeqHoundLLIDFromGi(params):
    a = SeqHoundDuo(["SeqHoundLLIDFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundLLIDFromGi([4501843])

# SeqHoundLLIDFromGiList: Fetches an NCBI's LocusLink database
#                         identifier associated with a list of
#                         sequences.
# CAVEAT: the order in the lists is not maintained.
def SeqHoundLLIDFromGiList(params):
    a = SeqHoundDuo(["SeqHoundLLIDFromGiList", "vnpgi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundLLIDFromGiList(["4501841,4557225"])

# SeqHoundLocusFromGi: Fetches a locus assignment for a sequence as
#                      found in NCBI's LocusLink database.
def SeqHoundLocusFromGi(params):
    a = SeqHoundDuo(["SeqHoundLocusFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundLocusFromGi([4501843])


### GENE ONTOLOGY HIERARCHY 

# WHA?! This is on the web api page, but not documented with the rest of
# the api. What gives?!
# SeqHoundGODBGetRecordByReference:
#def SeqHoundGODBGetRecordByReference(params):
#    a = SeqHoundDuo(["SeqHoundGODBGetRecordByReference", "refType", params[0]])
#    return a
#if __name__ == "__main__":
#    ret = SeqHoundGODBGetRecordByReference([""])

# SeqHoundGODBGetChildrenOf: This function operates on Gene Ontology
#                            (GO) vocabulary graphs. It retrieves a list
#                            of processes, functions or components
#                            situated directly below a given GO
#                            identifier in the graphs.
def SeqHoundGODBGetChildrenOf(params):
    a = SeqHoundDuo(["SeqHoundGODBGetChildrenOf", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetChildrenOf([7596])

# SeqHoundGODBGetParentOf: This function operates on Gene Ontology (GO)
#                          vocabulary graphs. It retrieves a list of
#                          processes, functions or components situated
#                          directly above a given GO identifier in the
#                          graphs.
# CAVEAT: Due to the logic of the GO hierarchy graphs, it is possible
#         that a GO identifier will have more than one parent
def SeqHoundGODBGetParentOf(params):
    a = SeqHoundDuo(["SeqHoundGODBGetParentOf", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetParentOf([7596])

# SeqHoundGODBGetAllAncestors: This function operates on Gene Ontology
#                              (GO) vocabulary graphs. It retrieves a
#                              list of all processes, functions or
#                              components situated above a given GO
#                              identifier in the graphs.
def SeqHoundGODBGetAllAncestors(params):
    a = SeqHoundDuo(["SeqHoundGODBGetAllAncestors", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetAllAncestors([7596])

# SeqHoundGODBGetAllChildren: This function operates on Gene Ontology
#                             (GO) vocabulary graphs. It retrieves a
#                             list all of processes, functions or
#                             components situated below a given GO
#                             identifier in the graphs.
def SeqHoundGODBGetAllChildren(params):
    a = SeqHoundDuo(["SeqHoundGODBGetAllChildren", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetAllChildren([6886])

# SeqHoundGODBGetNameByID: This function operates on Gene Ontology (GO)
#                          vocabulary graphs. It retrieves a name of a
#                          process, a function or a component for a
#                          given GO identifier.
def SeqHoundGODBGetNameByID(params):
    a = SeqHoundDuo(["SeqHoundGODBGetNameByID", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetNameByID([4866])

# SeqHoundGODBGetClassification: This function operates on Gene Ontology
#                                (GO) vocabulary graphs. It reports if a
#                                given GO identifier describes a
#                                cellular process, a cellular function
#                                or a cellular component.
def SeqHoundGODBGetClassification(params):
    a = SeqHoundDuo(["SeqHoundGODBGetClassification", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetClassification([4866])

# SeqHoundGODBGetHierarchyLevel: Not described by API Documentation.
# ***XXX***
def SeqHoundGODBGetHierarchyLevel(params):
    a = SeqHoundDuo(["SeqHoundGODBGetHierarchyLevel", "goid", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGODBGetHierarchyLevel([4866])


### COMPLETE GENOMES ANALYSIS

# SeqHoundAllGenomesWithScientificNames: Retrieves all complete genomes
#                                        from SeqHound and their
#                                        scientific names.
def SeqHoundGiAndNumNeighboursList(params):
    a = SeqHoundUni(["SeqHoundGiAndNumNeighboursList"])
    return a
if __name__ == "__main__":
    ret = SeqHoundGiAndNumNeighboursList([])

# SeqHoundAllGenomesWithNumProteins: Retrieve summary for complete
#                                    genomes and their protein count.
def SeqHoundAllGenomesWithNumProteins(params):
    a = SeqHoundUni(["SeqHoundAllGenomesWithNumProteins"])
    return a
if __name__ == "__main__":
    ret = SeqHoundAllGenomesWithNumProteins([])
	    

### RPS BLAST DOMAINS

# SeqHoundGetGisByNumberOfDomains: Fetches all sequences with a
#                                  specified number of domains
#                                  identified by Reverse Position
#                                  Specific BLAST using Conserved Domain
#                                  Database set of domains.
def SeqHoundGetGisByNumberOfDomains(params):
    a = SeqHoundDuo(["SeqHoundGetGisByNumberOfDomains", "numdom", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetGisByNumberOfDomains([6])

# SeqHoundGetDomainIdFromLabel: Returns one or more Conserved Domain
#                               Database (CDD) identifiers given a short
#                               non-unique label. The above labels are
#                               preferred amongst scientific community.
def SeqHoundGetDomainIdFromLabel(params):
    a = SeqHoundDuo(["SeqHoundGetDomainIdFromLabel", "label", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetDomainIdFromLabel(["COLFI"])

# SeqHoundGetGisByDomainId: Returns a short non-unique label given a
#                           domain for a Conserved Domain Database
#                           (CDD). The above labels are preferred
#                           amongst scientific community.
def SeqHoundGetGisByDomainId(params):
    a = SeqHoundDuo(["SeqHoundGetGisByDomainId", "domain_id", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetGisByDomainId(["smart00038"])

# SeqHoundGetDomainLabelFromDomainId: Returns a short non-unique label
#                                     given a domain for a Conserved
#                                     Domain Database (CDD). The above
#                                     labels are preferred amongst
#                                     scientific community.
def SeqHoundGetDomainLabelFromDomainId(params):
    a = SeqHoundDuo(["SeqHoundGetDomainLabelFromDomainId", "accession", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetDomainLabelFromDomainId(["smart00038"])

# SeqHoundGetGisByDomainIdAndEvalue: Fetches protein sequences on which
#                                    a domain from the Conserved Domain
#                                    Database (CDD) was identified by
#                                    Reverse Position Specific BLAST.
#                                    The function uses an E-value cutoff
#                                    for reporting results.
def SeqHoundGetGisByDomainIdAndEvalue(params):
    a = SeqHoundTri(["SeqHoundGetGisByDomainIdAndEvalue", "domain", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetGisByDomainIdAndEvalue(["smart00038", 0.001])

# SeqHoundGetDomainsFromGi: Fetches information about domains from the
#                           Conserved Domain Database (CDD) as assigned
#                           by Reverse Position Specific BLAST to a
#                           given protein sequence.
# COMMENT: The returning structure contains CDD domain identifier,
#          E-value, position, lenght of the alignment, N and C terminal
#          residues missing when compared to the consensus domain and
#          the total number of domains on a protein
def SeqHoundGetDomainsFromGi(params):
    a = SeqHoundDuo(["SeqHoundGetDomainsFromGi", "gi", params[0]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetDomainsFromGi([4557225])

# SeqHoundGetDomainsFromGiWithEvalue: etches information about domains
#                                     from the Conserved Domain Database
#                                     (CDD) as assigned by Reverse
#                                     Position Specific BLAST to a given
#                                     protein sequence. The function
#                                     uses an E-value cutoff for
#                                     reporting results.
# COMMENT: The returning structure contains CDD domain identifier,
#          E-value, position, lenght of the alignment, N and C terminal
#          residues missing when compared to the consensus domain and
#          the total number of domains on a protein
def SeqHoundGetDomainsFromGiWithEvalue(params):
    a = SeqHoundTri(["SeqHoundGetDomainsFromGiWithEvalue", "gi", params[0], "evalue", params[1]])
    return a
if __name__ == "__main__":
    ret = SeqHoundGetDomainsFromGiWithEvalue([4557225,0.001])


#######################################################################
# Start remainder of initializations here.
#######################################################################

# now test to make sure that the library works.
     
TEXT="** SeqHound installation at %s is" % SeqHoundSite

try:
    b = SeqHoundIsNetEntrezOn()
    print("seqhoundrweb.py: INITIATION ... SUCCESSFUL!\n")
except IOError, (x):
    print "IOError: ", x
    TEXT="%s NOT" % TEXT
    SeqStartError()

#######################################################################
# CVS Log Entries
#######################################################################
# $Log: SeqHoundRWeb.py,v $
# Revision 1.4  2003/05/31 02:04:59  pete
# Iterated version, brought some info up to date
#
# Revision 1.3  2003/05/30 20:39:06  pete
# checking in slight changes
#
# Revision 1.2  2003/05/30 18:13:17  pete
# Slight changes here and there, adding the setup.py script
#
# Revision 1.1.1.1  2003/05/28 15:49:03  pete
# Start of project; Initial wrapping of functions (~120) and testing. So
# far so good.
#
